@@ -41,11 +41,12 @@
 #endif
 
 #define FOUNDRY_VERSION_1_0 (G_ENCODE_VERSION (1, 0))
+#define FOUNDRY_VERSION_1_1 (G_ENCODE_VERSION (1, 1))
 
 #if FOUNDRY_MAJOR_VERSION == FOUNDRY_VERSION_1_0
 # define FOUNDRY_VERSION_PREV_STABLE (FOUNDRY_VERSION_1_0)
 #else
-# define FOUNDRY_VERSION_PREV_STABLE (G_ENCODE_VERSION (FOUNDRY_MAJOR_VERSION - 1, 0))
+# define FOUNDRY_VERSION_PREV_STABLE (G_ENCODE_VERSION (FOUNDRY_MAJOR_VERSION, FOUNDRY_MINOR_VERSION - 1))
 #endif
 
 /**
@@ -104,3 +105,16 @@
 #else
 # define FOUNDRY_AVAILABLE_IN_1_0 _FOUNDRY_EXTERN
 #endif
+
+#if FOUNDRY_VERSION_MIN_REQUIRED >= FOUNDRY_VERSION_1_1
+# define FOUNDRY_DEPRECATED_IN_1_1 FOUNDRY_DEPRECATED
+# define FOUNDRY_DEPRECATED_IN_1_1_FOR(f) FOUNDRY_DEPRECATED_FOR(f)
+#else
+# define FOUNDRY_DEPRECATED_IN_1_1 _FOUNDRY_EXTERN
+# define FOUNDRY_DEPRECATED_IN_1_1_FOR(f) _FOUNDRY_EXTERN
+#endif
+#if FOUNDRY_VERSION_MAX_ALLOWED < FOUNDRY_VERSION_1_1
+# define FOUNDRY_AVAILABLE_IN_1_1 FOUNDRY_UNAVAILABLE(1, 1)
+#else
+# define FOUNDRY_AVAILABLE_IN_1_1 _FOUNDRY_EXTERN
+#endif
